<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\DynamicPage;
use Illuminate\Http\Request;
use Carbon\Carbon;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;


class DynamicPageController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.dynamic_page', [
            'dynamic_pages' => DynamicPage::all(),
        ]);
    }

    public function dynamic_page_add()
    {
        return view('admin.dynamic_page_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'title' => 'required|unique:dynamic_pages',
            'slug' => 'unique:dynamic_pages',
            'full_content' => 'required'
        ]);

        if ($request->slug == '') {
            $slug = Str::slug($request->title);
        } else {
            $slug = Str::slug($request->slug);
        }

        $count = DynamicPage::where('slug', $slug)->count();
        if ($count != 0) {
            return back()->with('error', A_ERROR_SLUG_EXIST);
        }

        DynamicPage::create([
            'title' => $request->title,
            'slug' => $slug,
            'full_content' => $request->full_content,
            'meta_title' => $request->meta_title,
            'meta_description' => $request->meta_description
        ]);

        return Redirect()->route('admin.dynamic_page')->with('success', A_SUCCESS_DATA_ADD);
    }


    public function edit_page($id)
    {
        return view('admin.dynamic_page_edit', [
            'dynamic_page' => DynamicPage::find($id),
        ]);
    }


    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $request->validate([
            'title' => ['required',Rule::unique('dynamic_pages')->ignore($id),],
            'slug' => [Rule::unique('dynamic_pages')->ignore($id),],
            'full_content' => 'required'
        ]);

        if ($request->slug == '') {
            $slug = Str::slug($request->title);
        } else {
            $slug = Str::slug($request->slug);
        }

        $count = DynamicPage::where('slug', $slug)->where('id', '!=', $id)->count();
        if ($count != 0) {
            return back()->with('error', A_ERROR_SLUG_EXIST);
        }

        $dynamic_page = DynamicPage::findOrFail($id);
        $dynamic_page->title = $request->title;
        $dynamic_page->slug = $slug;
        $dynamic_page->full_content = $request->full_content;
        $dynamic_page->meta_title = $request->meta_title;
        $dynamic_page->meta_description = $request->meta_description;
        $dynamic_page->update();

        return Redirect()->route('admin.dynamic_page')->with('success', A_SUCCESS_DATA_UPDATE);
    }


    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        DynamicPage::find($id)->forceDelete();
        return Redirect()->route('admin.dynamic_page')->with('error', A_SUCCESS_DATA_DELETE);
    }
}
